<?php

namespace App\Http\Controllers;

use App\Models\Project;
use App\Models\ProjectImage;
use App\Models\Feature;
use Illuminate\Http\Request;
use File;
class ProjectController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    
    public function index()
    {
        $projects = Project::all();
        $features = Feature::where('status', true)->get();
        return view('admin.projects.index', compact('projects', 'features'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $features = Feature::where('status', true)->get();
        return view('admin.projects.create', compact('features'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required|max:30',
            'description' => 'required',
            'state' => 'required',
            'location' => 'required',
            'type' => 'required',
            'start_date' => 'required|date',
            'end_date' => 'required|date',
            'status' => 'required',
            'sold_out' => 'required',
            'bedrooms' => 'required',
            'bathrooms' => 'required',
            'price' => 'required',
            'subscription_fee' => 'required',
            // 'fee_breakdown' => 'required',
            // 'fee_breakdown_period' => 'required',
            'features' => 'required',
            'privacy_status' => 'required'
        ]);
        // dd("works");
        do {
            $prop_id = substr(str_shuffle('123456789ABCDEFGHIJKLMNOPQRSTUVWXYZ'),0, 8);
        } while (Project::where('prop_id', $prop_id)->exists());

        $features = implode(',', $request->features);
        
        $project = Project::create([
            'name' => $request->name,
            'description' => $request->description,
            'location' => $request->location,
            'state' => $request->state,
            'type' =>  $request->type,
            'start_date' => $request->start_date,
            'end_date' => $request->end_date,
            'status' => $request->status,
            'sold_out' => $request->sold_out,
            'bedrooms' => $request->bedrooms,
            'bathrooms' => $request->bathrooms,
            'price' => $request->price,
            'subscription_fee' => $request->subscription_fee,
            // 'fee_breakdown' => $request->fee_breakdown,
            // 'fee_breakdown_period' => $request->fee_breakdown_period,
            'features' => $features,
            'video_url' => $request->video_url,
            'privacy_status' => $request->privacy_status,
            'prop_id' => $prop_id
        ]);
        if($request->hasFile('images')) {
            $count = 1;
            foreach($request->file('images') as $image) {
                $destinationPath = 'public/project_images/';
                $filename = $count++.'.'.time().'.'.$image->getClientOriginalName();
                $image->move($destinationPath, $filename);

                $image = new ProjectImage([
                    'path' => $filename
                ]);
                $project->images()->save($image);
            }
        }
        return back()->with('success', $request->name . ' Project was successfully created.');
    }

    /**
     * Display the specified resource.
     *
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function show(Project $project)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function edit(Project $project, $projectID)
    {
        
        $getProject = Project::findOrFail($projectID);
        $features = Feature::where('status', true)->get();
        return view('admin.projects.edit', compact('getProject', 'features'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $projectID)
    {
        // $features = implode(',', $request->features);
        // dd($features);
        $getProject = Project::findOrFail($projectID);
        $features = implode(',', $request->features);
        $getProject->update([
            'name' => $request->name,
            'description' => $request->description,
            'location' => $request->location,
            'state' => $request->state,
            'type' =>  $request->type,
            'start_date' => $request->start_date,
            'end_date' => $request->end_date,
            'status' => $request->status,
            'sold_out' => $request->sold_out,
            'bedrooms' => $request->bedrooms,
            'bathrooms' => $request->bathrooms,
            'price' => $request->price,
            'subscription_fee' => $request->subscription_fee,
            // 'fee_breakdown' => $request->fee_breakdown,
            // 'fee_breakdown_period' => $request->fee_breakdown_period,
            'features' => $features,
            'video_url' => $request->video_url,
            'privacy_status' => $request->privacy_status,
            // 'prop_id' => $prop_id
        ]);
        
        return back()->with('success', $request->name . ' Project was successfully updated.');
    }

    public function updateProjectImage(Request $request)
    {
        $getProjectImage = ProjectImage::findOrFail($request->id);
        //dd($getProjectImage);
        $this->validate($request, [
            'image' => 'image|max:4000|required'
        ]);

        $oldimg = 'public/project_images/'.$getProjectImage->path;

        if (File::exists($oldimg)) {
            File::delete($oldimg);
        }

        $image = $request->file('image');
        if(!empty($image)){
            $destinationPath = 'public/project_images/';
            $filename = time().'.'.$image->getClientOriginalName();
            $image->move($destinationPath, $filename);

            $getProjectImage->update([
                'path'   => $filename,
            ]);

            return back()->with('success', 'Project Image: '. $request->filename . ' was successfully updated.');
        }

    }
    /**
     * Remove the specified resource from storage.
     *
     * @param  \App\Models\Project  $project
     * @return \Illuminate\Http\Response
     */
    public function preview($projectID)
    {
        $project = Project::findOrFail($projectID);
        $features = Feature::where('status', true)->get();
        return view('admin.projects.preview', compact('project', 'features'));
    }
}
